"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const parse5 = require("parse5");
const fs_1 = require("./utils/fs");
const html_1 = require("./utils/html");
const ta = parse5.treeAdapters.default;
function default_1(ctx) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const details = extractDetails(ctx);
        if (!details || details.engine !== 'cordova' || !details.platform) {
            return;
        }
        const platformWWW = path.resolve(ctx.project.dir, 'platforms', details.platform, 'platform_www');
        if (ctx.project.type === 'angular') {
            const p = path.resolve(ctx.project.dir, '.angular-cli.json');
            const j = JSON.parse(yield fs_1.readFile(p));
            const app = j.apps[0];
            app.assets.push({ glob: '**/*', input: platformWWW, output: './' });
            yield fs_1.writeFile(p, JSON.stringify(j, undefined, 2) + '\n');
        }
        const indexPath = path.resolve(ctx.project.srcDir, 'index.html');
        const origIndexPath = path.resolve(ctx.project.srcDir, 'index.html.orig');
        if (yield fs_1.exists(origIndexPath)) {
            yield fs_1.writeFile(indexPath, yield fs_1.readFile(origIndexPath));
            yield fs_1.unlink(origIndexPath);
        }
        const indexContents = yield fs_1.readFile(indexPath);
        const index = parse5.parse(indexContents);
        insertCordovaScript(index);
        const serialized = parse5.serialize(index);
        yield Promise.all([
            fs_1.writeFile(origIndexPath, indexContents),
            fs_1.writeFile(indexPath, serialized),
        ]);
    });
}
exports.default = default_1;
function extractDetails(ctx) {
    if (ctx.name !== 'build:before' && ctx.name !== 'serve:before') {
        return;
    }
    return ctx.name === 'serve:before' ? ctx.serve : ctx.build;
}
function insertCordovaScript(doc) {
    const rootNode = html_1.findElementByTag(doc.childNodes, 'html');
    if (!rootNode) {
        throw new Error('No root node in HTML file');
    }
    const namespaceURI = rootNode.namespaceURI;
    const headNode = html_1.findElementByTag(rootNode.childNodes, 'head');
    const bodyNode = html_1.findElementByTag(rootNode.childNodes, 'body');
    if (!headNode || !bodyNode) {
        throw new Error('No head or body node in HTML file');
    }
    const cdvattr = { name: 'src', value: 'cordova.js' };
    const scriptNodes = html_1.findElementsByTag([...headNode.childNodes, ...bodyNode.childNodes], 'script');
    const scriptNode = html_1.findElementByAttribute(scriptNodes, cdvattr);
    if (!scriptNode) {
        const el = ta.createElement('script', namespaceURI, [cdvattr]);
        ta.appendChild(headNode, el);
    }
}
